@@ -16,6 +16,7 @@ class AbstractRegression:
     _NbParms:int
     _Beta:NDArray
     _BetaFitError:NDArray
+    _BetaPredictionError:NDArray # trying this out
     
     _Residuals:NDArray
     _SSE:NDArray
@@ -170,6 +171,14 @@ class AbstractRegression:
         """
         return self._BetaFitError
 
+    @property
+    def BetaPredictionError(self) -> NDArray:
+        """
+        The prediction error on the fit parameters. Not sure if this is legit yet, 
+        but I computed it in a similar way than what is used for the EvalPredictionError. 
+        """
+        return self._BetaPredictionError
+
     def _computeFitStats(self):
         """
         Computes various useful fit stats:
