@@ -1,5 +1,5 @@
 import numpy as np
-from typing import Tuple
+from typing import Tuple, Union
 from .GenericCurveFit import GenericCurveFit
 from .utilities import FFTGuess
 from nptyping import NDArray
@@ -31,10 +31,10 @@ class CosineFit(GenericCurveFit):
 
         return out
 
-    def __init__(self, x:NDArray, y:NDArray, p0:NDArray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
+    def __init__(self, x:NDArray, y:NDArray, p0:Union[Tuple[float,...],NDArray]=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, warningEnabled:bool=True, **kwargs):
 
         if p0 is None:
             # Uses the fft to guess good p0 values
-            p0 = FFTGuess(x, y)
+            p0 = FFTGuess(x, y, warningEnabled=warningEnabled)
 
         super(CosineFit, self).__init__(x, y, self.FitFunc, self.Jacobian, p0, bounds, confidenceInterval, simult, **kwargs )
\ No newline at end of file
