@@ -2,17 +2,18 @@ import numpy as np
 from typing import Tuple
 from .GenericCurveFit import GenericCurveFit
 from .utilities import FFTGuess
+from nptyping import NDArray
 
 class Exponential(GenericCurveFit):
     
-    def FitFunc(self, x:np.ndarray, a:float, b:float, c:float) -> np.ndarray:
+    def FitFunc(self, x:NDArray, a:float, b:float, c:float) -> NDArray:
         """
         An exponantial function that goes like
         $$ y = a e^{bx} + c $$
         """
         return a * np.exp(b*x) + c
 
-    def Jacobian(self, x:np.ndarray, a:float, b:float, c:float) -> np.ndarray:
+    def Jacobian(self, x:NDArray, a:float, b:float, c:float) -> NDArray:
         """
         The jacobian of the exponential fit function. 
         Meant to return a matrix of shape [x.shape[0], 3], where
@@ -26,5 +27,5 @@ class Exponential(GenericCurveFit):
 
         return out
 
-    def __init__(self, x:np.ndarray, y:np.ndarray, p0:np.ndarray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
+    def __init__(self, x:NDArray, y:NDArray, p0:NDArray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
         super(Exponential, self).__init__(x, y, self.FitFunc, self.Jacobian, p0, bounds, confidenceInterval, simult, **kwargs )
\ No newline at end of file
