@@ -84,7 +84,7 @@ class GenericCurveFit(AbstractRegression):
         """
         return self._VARS
 
-    def __init__(self, x:NDArray, y:NDArray, fitFunc:Callable, jacobian:Callable, p0:NDArray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
+    def __init__(self, x:NDArray, y:NDArray, fitFunc:Callable, jacobian:Callable, p0:Union[Tuple[float,...],NDArray]=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
         self._initialized = False
         self._FitFunc = fitFunc
         self._Jacobian = jacobian
